@@ -108,7 +108,7 @@ void show_usage(void)
 	fprintf(stderr, "usage: %s [-g geom] [-d dpy] [-f cfgfile] [-b btnfile] "\
 		"[-F <font>] [-v] [-s] [-n]\n",app_name);
 	fprintf(stderr, "\n");
-	fprintf(stderr, " wmbutton version %s\n", VER_STR);
+	fprintf(stderr, " wmbutton version %s\n", PACKAGE_VERSION);
 	fprintf(stderr, "\n");
 	fprintf(stderr, "-g <geometry>  Window Geometry - ie: 64x64+10+10\n");
 	fprintf(stderr, "-d <display>   Display - ie: 127.0.0.1:0.0\n");
@@ -191,6 +191,23 @@ void RunAppN(int app)
 }
 /***********************************************************************/
 
+/***********************************************************************
+ * canOpenFile(const char *path)
+ *
+ * Check if the file at a given path can be opened.
+ ***********************************************************************/
+int canOpenFile(const char *path)
+{
+	FILE *fp;
+
+	if ((fp = fopen(path, "r")) == NULL)
+		return 0;
+	else {
+		fclose(fp);
+		return 1;
+	}
+}
+
 /***********************************************************************
  * Parse(int app)
  *
