@@ -1,7 +1,6 @@
 /***********************************************************************
  *   Code is based on wmppp, wmload, wmtime, wmcp, and asbutton
  *   Author: Edward H. Flora <ehflora@ksu.edu>
- *   Ver 0 Rel 6.1    Jan 23, 2005
  *
  *   Contributors:
  *              Christian 'Greek0' Aichinger <Greek0@gmx.net>
@@ -111,6 +110,14 @@ int main(int argc, char **argv)
 	/* Parse Command Line Arguments */
 	parseargs(argc, argv);
 
+	/* Catch fire if no configuration file exists */
+	if (!canOpenFile(Config.configfile)) {
+		if(!canOpenFile(CONFIGGLOBAL)) {
+			err_mess(FAILCONF, Config.configfile);
+			return (1);
+		}
+	}
+
 	/* Open Display */
 	if ((display = XOpenDisplay(Config.Display_str)) == NULL)
 		err_mess(FAILDISP, Config.Display_str);
