@@ -19,9 +19,6 @@
 #define CONFIGGLOBAL "/etc/wmbutton.conf" /* system configuration */
 #define BUTTONFILENAME "/.wmbutton.xpm"
 
-/******  Version Number *************************************************/
-#define VER_STR       "0.7.0"     /* Version Number String */
-
 /******  Define Error Codes *********************************************/
 #define FAILDISP      20
 #define FAILSWIN      21
@@ -84,6 +81,7 @@ void parseargs(int argc, char **argv);
 char *readln(FILE *fp);            /* read line from file, return pointer to it */
 void err_mess(int err, char *str); /* Error Handling Routine */
 void show_usage(void);             /* show usage message to stderr */
+int canOpenFile(const char *path);
 int flush_expose(Window w);
 
 
